@@ -1,6 +1,6 @@
 import os
 
-version = '0.0.4'
+version = '0.0.5'
 
 # 开发
 login_base_url_develop = 'http://develop.tentech.com.cn:8080'
@@ -13,9 +13,9 @@ cloud_base_url_stage = 'http://stage.tentech.com.cn:8081'
 docker_registry_stage = 'stage.tentech.com.cn:5000'
 
 # 生产
-login_base_url_master = 'http://flowhub.com.cn:8080'
-cloud_base_url_master = 'http://flowhub.com.cn:8081'
-docker_registry_master = 'flowhub.com.cn:5000'
+login_base_url_master = 'http://www.flowhb.com.cn:8080'
+cloud_base_url_master = 'http://www.flowhub.com.cn:8081'
+docker_registry_master = 'www.flowhub.com.cn:5000'
 
 cli_dir = '.cli'
 USER_BASE_PATH = os.path.expanduser('~')
